@@ -3,7 +3,7 @@
 # Example script used to execute an alert action.
 #
 #  - in CPU alerts the current value is the last 15min load average
-#  - in DISK alerts the current value is the root filesystem usage (%)
+#  - in FS alerts the current value is the root filesystem usage (%)
 #
 
 if [ $# != 3 ] ; then
@@ -25,5 +25,5 @@ The current value is: $current_value
 
 Please take proper actions to correct this situation.
 EOF
-) | mail -s "WARNING: Monitorix alert" root
+) | mail -s "WARNING: Monitorix alert!" root
 
